@@ -19,7 +19,6 @@ from rich.progress import track
 import xarray as xr
 
 from gprof_nn import sensors
-from gprof_nn.data.preprocessor import PreprocessorFile, run_preprocessor
 from gprof_nn.definitions import DATABASE_MONTHS
 from gprof_nn.logging import get_console
 
@@ -56,11 +55,11 @@ class L1CFile:
             month = date.month
             day = date.day
             path = Path(path) / f"{year:02}{month:02}" / f"{year:02}{month:02}{day:02}"
-            files = path.glob(sensor.l1c_file_prefix + f"*.{granule:06}.*.HDF5")
+            files = path.glob(sensor.l1c_file_prefix + f"*.{granule:06}.*{sensor.l1c_version}.HDF5")
         else:
             path = Path(path)
             files = path.glob(
-                "**/" + sensor.l1c_file_prefix + f"*.{granule:06}.*.HDF5"
+                "**/" + sensor.l1c_file_prefix + f"*.{granule:06}.*{sensor.l1c_version}.HDF5"
             )
 
         files = list(files)
@@ -70,7 +69,6 @@ class L1CFile:
                 f"went wrong. Found the following files: {files}"
             )
         try:
-            f = files[0]
             f = next(iter(files))
             return L1CFile(f)
         except StopIteration:
@@ -99,7 +97,7 @@ class L1CFile:
         month = date.month
         day = date.day
         data_path = Path(path) / f"{year:02}{month:02}" / f"{year:02}{month:02}{day:02}"
-        files = list(data_path.glob(sensor.l1c_file_prefix + "*.HDF5"))
+        files = list(data_path.glob(sensor.l1c_file_prefix + f"*{sensor.l1c_version}.HDF5"))
 
         # Add files from following day.
         date_f = date + pd.DateOffset(1)
@@ -107,7 +105,7 @@ class L1CFile:
         month = date_f.month
         day = date_f.day
         data_path = Path(path) / f"{year:02}{month:02}" / f"{year:02}{month:02}{day:02}"
-        files += list(data_path.glob(sensor.l1c_file_prefix + "*.HDF5"))
+        files += list(data_path.glob(sensor.l1c_file_prefix + f"*{sensor.l1c_version}.HDF5"))
 
         # Add files from previous day.
         date_f = date - pd.DateOffset(1)
@@ -116,9 +114,9 @@ class L1CFile:
         day = date_f.day
         data_path = Path(path) / f"{year:02}{month:02}" / f"{year:02}{month:02}{day:02}"
 
-        files += list(data_path.glob(sensor.l1c_file_prefix + "*.HDF5"))
+        files += list(data_path.glob(sensor.l1c_file_prefix + f"*{sensor.l1c_version}.HDF5"))
 
-        files += list(path.glob(sensor.l1c_file_prefix + "*.HDF5"))
+        files += list(path.glob(sensor.l1c_file_prefix + f"*{sensor.l1c_version}.HDF5"))
 
         start_times = []
         end_times = []
@@ -135,6 +133,7 @@ class L1CFile:
         end_times = np.array(end_times)
         date = date.to_datetime64()
 
+
         if len(start_times) == 0 or len(end_times) == 0:
             raise ValueError("No file found for the requested date.")
         inds = np.where((start_times <= date) * (end_times >= date))[0]
@@ -172,24 +171,24 @@ class L1CFile:
         data_path = Path(path) / f"{year:02}{month:02}" / f"{year:02}{month:02}{day:02}"
         files = list(
             data_path.glob(
-                sensor.l1c_file_prefix + f"*{date.year:04}{month:02}{day:02}*.HDF5"
+                sensor.l1c_file_prefix + f"*{date.year:04}{month:02}{day:02}*{sensor.l1c_version}.HDF5"
             )
         )
         files += list(
             path.glob(
-                sensor.l1c_file_prefix + f"*{date.year:04}{month:02}{day:02}*.HDF5"
+                sensor.l1c_file_prefix + f"*{date.year:04}{month:02}{day:02}*{sensor.l1c_version}.HDF5"
             )
         )
-        for f in files:
+        for l1c_file in files:
             try:
-                f = L1CFile(f)
+                l1c_file = L1CFile(l1c_file)
             except Exception:
                 continue
             if roi is not None:
-                if f.covers_roi(roi):
-                    yield f
+                if l1c_file.covers_roi(roi):
+                    yield l1c_file
             else:
-                yield f
+                yield l1c_file
 
     def __init__(self, path):
         """
@@ -215,7 +214,6 @@ class L1CFile:
                 date=self.start_time
             )
 
-
     @property
     def start_time(self):
         import h5py
@@ -368,12 +366,9 @@ class L1CFile:
                         scan_start * scaling,
                         scan_end * scaling
                     )
-                    print(scaling, scan_range)
-
                     g = output.create_group(group_name)
                     for name, item in input[group_name].items():
                         if isinstance(item, h5py.Dataset):
-                            print(name, item.shape,)
                             shape = item.shape
                             g.create_dataset(
                                 name,
@@ -489,6 +484,18 @@ class L1CFile:
                 tbs.append(input["S2/Tc"][:][indices])
             if "S3" in input.keys():
                 tbs.append(input["S3/Tc"][:][indices])
+            if "S4" in input.keys():
+                tbs.append(input["S4/Tc"][:][indices])
+            if "S5" in input.keys():
+                tbs_s = input["S5/Tc"][:][indices]
+                if tbs_s.shape[-2] > tbs[-1].shape[-2]:
+                    tbs_s = tbs_s[..., ::2, :]
+                tbs.append(tbs_s)
+            if "S6" in input.keys():
+                tbs_s = input["S6/Tc"][:][indices]
+                if tbs_s.shape[-2] > tbs[-1].shape[-2]:
+                    tbs_s = tbs_s[..., ::2, :]
+                tbs.append(tbs_s)
 
             n_pixels = max([array.shape[1] for array in tbs])
             tbs_r = []
@@ -592,6 +599,7 @@ def process_l1c_file(l1c_filename, sensor):
             the data originates.
     """
     import gprof_nn.logging
+    from gprof_nn.data.preprocessor import run_preprocessor
 
     data_pp = run_preprocessor(l1c_filename, sensor=sensor)
     return extract_scenes(data_pp)
