@@ -3,19 +3,17 @@
 gprof_nn.data.sim
 =================
 
-This module defines a class to read the simulator output files (*.sim) that
-contain the atmospheric profiles and corresponding simulated brightness
-temperatures.
+This module defines a class to read the output files of the GPROF
+simulator (*.sim), which contain the atmospheric profiles and
+corresponding simulated brightness temperatures.
 
-The module also provides functionality to extract the training data for the
-GPROF-NN algorithm from these files.
+The module also provides functionality to extract the training data
+ for the GPROF-NN algorithm from these files.
 """
 from concurrent import futures
 from datetime import datetime
 import logging
-import os
 from pathlib import Path
-import subprocess
 import tempfile
 
 import numpy as np
@@ -32,7 +30,7 @@ from gprof_nn.definitions import (
     LEVELS,
     DATABASE_MONTHS,
     PROFILE_NAMES,
-    SEAICE_YEARS
+    SEAICE_YEARS,
 )
 
 from gprof_nn.coordinates import latlon_to_ecef
@@ -70,6 +68,7 @@ CHANNEL_INDICES = {
     "SSMI": [2, 3, 4, 6, 7, 8, 9],
     "SSMIS": [2, 3, 4, 6, 7, 8, 9, 11, 12, 13, 14],
     "AMSR2": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9],
+    "AMSRE": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9],
 }
 
 
@@ -91,7 +90,6 @@ class SimFile:
             file.
         data: Numpy structured array containing raw data of the file.
     """
-
     @classmethod
     def find_files(cls, path, sensor=sensors.GMI, day=None):
         """
@@ -102,8 +100,8 @@ class SimFile:
             path: Root of the directory tree in which to look for .sim
                 files.
             sensor: The sensor for which to find .sim files.
-            day: If given search is restricted to the given day within
-                each month.
+            day: Restricts the searth to given day of the month if
+                given.
 
         Return:
             A list containing the found .sim files.
@@ -151,7 +149,7 @@ class SimFile:
         xarray dataset.
 
         Args:
-            input_data: xarray dataset containing the input data from
+            input_data: ``xarray.Dataset`` containing the input data from
                 the preprocessor.
             targets: List of retrieval target variables to extract from
                 the sim file.
@@ -346,12 +344,12 @@ class SimFile:
         minute = dataset["scan_time"].data["minute"]
         second = dataset["scan_time"].data["second"]
         dates = (
-            year.astype("datetime64[Y]") +
-            month.astype("timedelta64[M]") +
-            day.astype("timedelta64[D]") +
-            hour.astype("timedelta64[h]") +
-            minute.astype("timedelta64[m]") +
-            second.astype("timedelta64[s]")
+            year.astype("datetime64[Y]")
+            + month.astype("timedelta64[M]")
+            + day.astype("timedelta64[D]")
+            + hour.astype("timedelta64[h]")
+            + minute.astype("timedelta64[m]")
+            + second.astype("timedelta64[s]")
         )
         dataset["scan_time"] = (("samples",), dates)
 
@@ -445,10 +443,12 @@ def _extract_scenes(data):
         j_start = 0
         had_scene = False
         while j_start + j_step <= j_end:
-            subscene = data[{
-                "scans": slice(i_start, i_start + n),
-                "pixels": slice(j_start, j_start + n)
-            }]
+            subscene = data[
+                {
+                    "scans": slice(i_start, i_start + n),
+                    "pixels": slice(j_start, j_start + n),
+                }
+            ]
             surface_precip = subscene["surface_precip"].data
             if np.isfinite(surface_precip).sum() > 50:
                 scenes.append(subscene)
@@ -597,6 +597,7 @@ def process_sim_file(sim_filename, sensor, configuration, era5_path, log_queue=N
 
     if log_queue is not None:
         gprof_nn.logging.configure_queue_logging(log_queue)
+    LOGGER = logging.getLogger(__name__)
     LOGGER.info("Processing sim file %s.", sim_filename)
 
     # Load sim file and corresponding GMI L1C file.
@@ -610,15 +611,20 @@ def process_sim_file(sim_filename, sensor, configuration, era5_path, log_queue=N
         l1c_file.filename, sensor=sensor, configuration=configuration, robust=False
     )
     data_pp = data_pp.drop_vars(
-        ["earth_incidence_angle", "sunglint_angle", "quality_flag",
-         "wet_bulb_temperature", "lapse_rate"]
+        [
+            "earth_incidence_angle",
+            "sunglint_angle",
+            "quality_flag",
+            "wet_bulb_temperature",
+            "lapse_rate",
+        ]
     )
     if isinstance(sensor, sensors.CrossTrackScanner):
-        data_pp["eart_incidence_angle"] = (
-            ("scans", "pixels"), np.ones_like(data_pp.two_meter_temperature.data)
+        data_pp["earth_incidence_angle"] = (
+            ("scans", "pixels"),
+            np.ones_like(data_pp.two_meter_temperature.data),
         )
 
-
     if data_pp is None:
         return None
 
@@ -651,13 +657,14 @@ def process_sim_file(sim_filename, sensor, configuration, era5_path, log_queue=N
 
     # If we are dealing with GMI add precip from ERA5.
     if sensor == sensors.GMI:
-        LOGGER.debug("Adding ERA5 precip for file %s.", sim_filename)
-        start_time = data_pp["scan_time"].data[0]
-        end_time = data_pp["scan_time"].data[-1]
-        LOGGER.debug("Loading ERA5 data: %s %s", start_time, end_time)
-        era5_data = _load_era5_data(start_time, end_time, era5_path)
-        _add_era5_precip(data_pp, l1c_data, era5_data)
-        LOGGER.debug("Added era5 precip.")
+        if era5_path is not None:
+            LOGGER.debug("Adding ERA5 precip for file %s.", sim_filename)
+            start_time = data_pp["scan_time"].data[0]
+            end_time = data_pp["scan_time"].data[-1]
+            LOGGER.debug("Loading ERA5 data: %s %s", start_time, end_time)
+            era5_data = _load_era5_data(start_time, end_time, era5_path)
+            _add_era5_precip(data_pp, l1c_data, era5_data)
+            LOGGER.debug("Added era5 precip.")
     # Else set to missing.
     else:
         sea_ice = (surface_type == 2) + (surface_type == 16)
@@ -687,6 +694,7 @@ def process_mrms_file(sensor, mrms_filename, configuration, day, log_queue=None)
 
     if log_queue is not None:
         gprof_nn.logging.configure_queue_logging(log_queue)
+    LOGGER = logging.getLogger(__name__)
     LOGGER.info("Processing MRMS file %s.", mrms_filename)
     mrms_file = MRMSMatchFile(mrms_filename)
     mrms_sensor = mrms_file.sensor
@@ -702,16 +710,12 @@ def process_mrms_file(sensor, mrms_filename, configuration, day, log_queue=None)
     )
 
     scenes = []
-    LOGGER.debug(
-        "Found %s L1C file for MRMS file %s.",
-        len(l1c_files),
-        mrms_filename
-    )
+    LOGGER.debug("Found %s L1C file for MRMS file %s.", len(l1c_files), mrms_filename)
     for file in l1c_files:
         # Extract scans over CONUS ans run preprocessor.
         _, f_roi = tempfile.mkstemp()
         try:
-            file.extract_scans(CONUS, f_roi)
+            file.extract_scans(CONUS, f_roi, min_scans=221)
             data_pp = run_preprocessor(
                 f_roi, configuration=configuration, sensor=sensor, robust=False
             )
@@ -748,7 +752,6 @@ def process_mrms_file(sensor, mrms_filename, configuration, day, log_queue=None)
         if new_scenes is not None:
             scenes.append(new_scenes)
 
-
     if scenes:
         dataset = xr.concat(scenes, "samples")
         dataset["source"] = (("samples",), np.ones(dataset.samples.size, dtype=np.int8))
@@ -773,12 +776,12 @@ def process_l1c_file(l1c_filename, sensor, configuration, era5_path, log_queue=N
 
     if log_queue is not None:
         gprof_nn.logging.configure_queue_logging(log_queue)
+    LOGGER = logging.getLogger(__name__)
     LOGGER.info("Starting processing L1C file %s.", l1c_filename)
 
     data_pp = run_preprocessor(
         l1c_filename, sensor=sensor, configuration=configuration, robust=False
     )
-    l1c_file = L1CFile(l1c_filename)
 
     # Drop unneeded variables.
     drop = ["sunglint_angle", "quality_flag", "wet_bulb_temperature", "lapse_rate"]
@@ -790,7 +793,7 @@ def process_l1c_file(l1c_filename, sensor, configuration, era5_path, log_queue=N
         return None
     if data_pp.channels.size > sensor.n_chans:
         if sensor.sensor_name in CHANNEL_INDICES:
-            ch_inds = CHANNEL_INDICES[self.sensor.sensor_name]
+            ch_inds = CHANNEL_INDICES[sensor.sensor_name]
             data_pp = data_pp[{"channels": ch_inds}]
 
     data_pp = add_targets(data_pp, sensor)
@@ -961,6 +964,66 @@ def add_brightness_temperatures(data, sensor):
 ###############################################################################
 
 
+def get_l1c_files_for_seaice(sensor, day):
+    """
+    Finds sensors L1C files that should be used to extract
+    ERA5 collocations.
+
+    The function first checks whether there is a specific SEAICE year
+    defined for the given sensor in ``gprof_nn.definitions``. If that
+    is not the case it will look for L1C files for the current database
+    period.
+
+    If the above doesn't produce any L1C files, then GMI collocations
+    with ERA5 are used.
+
+    Args:
+        sensor: Sensor for which the data is to be extracted.
+
+    Return:
+        List of L1C filenames to process.
+    """
+    # Collect L1C files to process.
+    l1c_file_path = sensor.l1c_file_path
+    l1c_files = []
+
+    # Get L1C for specific year ...
+    if sensor.name in SEAICE_YEARS:
+        year = SEAICE_YEARS[sensor.name]
+        for month in range(1, 13):
+            try:
+                date = datetime(year, month, day)
+                l1c_files += list(L1CFile.find_files(
+                    date, l1c_file_path, sensor=sensor
+                ))
+            except ValueError:
+                pass
+    else:
+        for year, month in DATABASE_MONTHS:
+            try:
+                date = datetime(year, month, day)
+                l1c_files += list(L1CFile.find_files(
+                    date, l1c_file_path, sensor=sensor
+                ))
+            except ValueError:
+                pass
+
+    # If no L1C files are found use GMI co-locations.
+    if len(l1c_files) < 1:
+        for year, month in DATABASE_MONTHS:
+            try:
+                date = datetime(year, month, day)
+                l1c_file_path = sensors.GMI.l1c_file_path
+                l1c_files += list(L1CFile.find_files(
+                    date, l1c_file_path, sensor=sensors.GMI
+                ))
+            except ValueError:
+                pass
+    l1c_files = [f.filename for f in l1c_files]
+    l1c_files = np.random.permutation(l1c_files)
+    return l1c_files
+
+
 class SimFileProcessor:
     """
     Processor class that manages the extraction of GPROF training data. A
@@ -984,7 +1047,7 @@ class SimFileProcessor:
             output_file: The file in which to store the extracted data.
             sensor: Sensor object defining the sensor for which to extract
                 training data.
-            era_5_path: Path to the root of the directory tree containing
+            era5_path: Path to the root of the directory tree containing
                 ERA5 data.
             n_workers: The number of worker processes to use.
             day: Day of the month for which to extract the data.
@@ -994,12 +1057,10 @@ class SimFileProcessor:
         self.sensor = sensor
         self.configuration = configuration
 
-        if era5_path is None:
-            raise ValueError(
-                "The 'era5_path' argument must be provided in order to process"
-                " any sim files."
-            )
-        self.era5_path = Path(era5_path)
+        self.era5_path = era5_path
+        if self.era5_path is not None:
+            self.era5_path = Path(self.era5_path)
+
         self.pool = futures.ProcessPoolExecutor(max_workers=n_workers)
 
         if day is None:
@@ -1015,68 +1076,61 @@ class SimFileProcessor:
         stores the names of the produced result files in the ``processed`` attribute
         of the driver.
         """
+        # Collect simulator files to process.
         sim_file_path = self.sensor.sim_file_path
-        sim_files = SimFile.find_files(sim_file_path, sensor=self.sensor, day=self.day)
-        sim_files = np.random.permutation(sim_files)
-
-        mrms_file_path = self.sensor.mrms_file_path
-        if mrms_file_path is None:
-            mrms_files = MRMSMatchFile.find_files(
-                sensors.GMI.mrms_file_path, sensor=sensors.GMI
+        if self.sensor.sim_file_path is not None:
+            sim_files = SimFile.find_files(
+                sim_file_path,
+                sensor=self.sensor,
+                day=self.day
             )
+            sim_files = np.random.permutation(sim_files)
         else:
-            mrms_files = MRMSMatchFile.find_files(mrms_file_path, sensor=self.sensor)
-        mrms_files = np.random.permutation(mrms_files)
+            sim_files = []
 
+        # Collect MRMS files to process.
+        if self.sensor.mrms_file_path is not None:
+            mrms_file_path = self.sensor.mrms_file_path
+            if mrms_file_path is None:
+                mrms_files = MRMSMatchFile.find_files(
+                    sensors.GMI.mrms_file_path, sensor=sensors.GMI
+                )
+            else:
+                if hasattr(self.sensor, "mrms_sensor"):
+                    mrms_sensor = self.sensor.mrms_sensor
+                else:
+                    mrms_sensor = self.sensor
+                mrms_files = MRMSMatchFile.find_files(
+                    mrms_file_path,
+                    sensor=mrms_sensor
+                )
+            mrms_files = np.random.permutation(mrms_files)
+        else:
+            mrms_files = []
+
+        # Collect L1C files to process.
         l1c_file_path = self.sensor.l1c_file_path
-        l1c_files = []
-
-        # Get L1C for specific year ...
-        if self.sensor.name in SEAICE_YEARS:
-            year = SEAICE_YEARS[self.sensor.name]
-            for month in range(1, 13):
-                try:
-                    date = datetime(year, month, self.day)
-                    l1c_files += L1CFile.find_files(date, l1c_file_path, sensor=self.sensor)
-                except ValueError:
-                    pass
-        # Or database period
+        if self.era5_path is not None:
+            l1c_files = get_l1c_files_for_seaice(self.sensor, self.day)[:100]
         else:
-            for year, month in DATABASE_MONTHS:
-                try:
-                    date = datetime(year, month, self.day)
-                    l1c_files += L1CFile.find_files(date, l1c_file_path, sensor=self.sensor)
-                except ValueError:
-                    pass
-
-        # If no L1C files are found use GMI co-locations.
-        if len(l1c_files) < 1:
-            for year, month in DATABASE_MONTHS:
-                try:
-                    date = datetime(year, month, self.day)
-                    l1c_file_path = sensors.GMI.l1c_file_path
-                    l1c_files += L1CFile.find_files(
-                        date, l1c_file_path, sensor=sensors.GMI
-                    )
-                except ValueError:
-                    pass
-        l1c_files = [f.filename for f in l1c_files]
-        l1c_files = np.random.permutation(l1c_files)
+            l1c_files = []
 
         n_sim_files = len(sim_files)
-        LOGGER.debug("Found %s SIM files.", n_sim_files)
+        LOGGER.info("Found %s SIM files.", n_sim_files)
         n_mrms_files = len(mrms_files)
-        LOGGER.debug("Found %s MRMS files.", n_mrms_files)
+        LOGGER.info("Found %s MRMS files.", n_mrms_files)
         n_l1c_files = len(l1c_files)
-        LOGGER.debug("Found %s L1C files.", n_l1c_files)
+        LOGGER.info("Found %s L1C files.", n_l1c_files)
         i = 0
 
         # Submit tasks interleaving .sim and MRMS files.
         log_queue = gprof_nn.logging.get_log_queue()
         tasks = []
+        files = []
         while i < max(n_sim_files, n_mrms_files, n_l1c_files):
             if i < n_sim_files:
                 sim_file = sim_files[i]
+                files.append(sim_file)
                 tasks.append(
                     self.pool.submit(
                         process_sim_file,
@@ -1089,10 +1143,15 @@ class SimFileProcessor:
                 )
             if i < n_mrms_files:
                 mrms_file = mrms_files[i]
+                files.append(mrms_file)
+                if hasattr(self.sensor, "mrms_sensor"):
+                    sensor = self.sensor.mrms_sensor
+                else:
+                    sensor = self.sensor
                 tasks.append(
                     self.pool.submit(
                         process_mrms_file,
-                        self.sensor,
+                        sensor,
                         mrms_file,
                         self.configuration,
                         self.day,
@@ -1101,6 +1160,7 @@ class SimFileProcessor:
                 )
             if i < n_l1c_files:
                 l1c_file = l1c_files[i]
+                files.append(l1c_file)
                 tasks.append(
                     self.pool.submit(
                         process_l1c_file,
@@ -1125,23 +1185,23 @@ class SimFileProcessor:
         chunk = 1
 
         with Progress(console=get_console()) as progress:
-            gprof_nn.logging.set_log_level("INFO")
             pbar = progress.add_task("Extracting data:", total=len(tasks))
-            for task in tasks:
+            for task, filename in zip(tasks, files):
                 # Log messages from processes.
                 task_done = False
                 dataset = None
                 while not task_done:
                     try:
                         gprof_nn.logging.log_messages()
-                        dataset = task.result(timeout=1)
+                        dataset = task.result()
                         task_done = True
                     except futures.TimeoutError:
                         pass
                     except Exception as exc:
-                        LOGGER.warning(
+                        LOGGER.error(
                             "The following error was encountered while "
-                            "collecting results: %s",
+                            "processing file %s results: %s",
+                            str(filename),
                             exc,
                         )
                         get_console().print_exception()
@@ -1156,19 +1216,20 @@ class SimFileProcessor:
                         filename = output_path / (output_file + f"_{chunk:02}.nc")
                         dataset.attrs["sensor"] = self.sensor.name
                         dataset.to_netcdf(filename)
-                        #subprocess.run(["lz4", "-f", "--rm", filename], check=True)
+                        # subprocess.run(["lz4", "-f", "--rm", filename], check=True)
                         LOGGER.info("Finished writing file: %s", filename)
                         datasets = []
                         chunk += 1
 
-        # Store dataset with sensor name as attribute.
-        dataset = xr.concat(datasets, "samples")
-        filename = output_path / (output_file + f"_{chunk:02}.nc")
-        dataset.attrs["sensor"] = self.sensor.name
-        dataset.attrs["configuration"] = self.configuration
-        LOGGER.info("Writing file: %s", filename)
-        dataset.to_netcdf(filename)
-        #subprocess.run(["lz4", "-f", "--rm", filename], check=True)
+        if len(datasets) > 0:
+            # Store dataset with sensor name as attribute.
+            dataset = xr.concat(datasets, "samples")
+            filename = output_path / (output_file + f"_{chunk:02}.nc")
+            dataset.attrs["sensor"] = self.sensor.name
+            dataset.attrs["configuration"] = self.configuration
+            LOGGER.info("Writing file: %s", filename)
+            dataset.to_netcdf(filename)
+            # subprocess.run(["lz4", "-f", "--rm", filename], check=True)
 
         # Explicit clean up to avoid memory leak.
         del datasets
