@@ -19,10 +19,30 @@ from rich.console import Console
 # Basic logging
 #
 
-_LOG_LEVEL = os.environ.get('GPROF_NN_LOG_LEVEL', 'INFO').upper()
-
-
+_LOG_LEVEL = os.environ.get("GPROF_NN_LOG_LEVEL", "INFO").upper()
 _CONSOLE = Console()
+_HANDLER = RichHandler(console=_CONSOLE)
+
+# The parent logger for the module.
+LOGGER = logging.getLogger("gprof_nn")
+LOGGER.setLevel(_LOG_LEVEL)
+
+
+def enable_file_logging(filename):
+    """
+    Enable logging to a file.
+
+    Args:
+        filename: Filename of the file to which to write the log.
+    """
+    handler = logging.FileHandler(filename)
+    formatter = logging.Formatter(
+        '{levelname} [{name:<30}] :: {message}',
+        style="{"
+    )
+    handler.setLevel("DEBUG")
+    handler.setFormatter(formatter)
+    LOGGER.addHandler(handler)
 
 
 def get_console():
@@ -37,27 +57,18 @@ def set_log_level(level):
     Args:
         level: String defining the log level.
     """
-    logging.basicConfig(
-        level=level.upper(),
-        format="%(message)s",
-        datefmt="[%X]",
-        handlers=[RichHandler(console=get_console())]
-    )
-
-
-logging.basicConfig(
-    level=_LOG_LEVEL,
-    format="%(message)s",
-    datefmt="[%X]",
-    handlers=[RichHandler(level=_LOG_LEVEL, console=get_console())]
-)
+    # logging.basicConfig(
+    #    level=level.upper(),
+    #    format="%(message)s",
+    #    datefmt="[%X]",
+    #    handlers=[_HANDLER]
+    # )
 
 
 #
 # Multi-process logging.
 #
 
-
 _LOG_QUEUE = None
 
 
@@ -78,14 +89,10 @@ def configure_queue_logging(log_queue):
     Args:
         log_queue: The log queue provided from the parent process.
     """
-    log_level = os.environ.get('GPROF_NN_LOG_LEVEL', 'INFO').upper()
+    logger = logging.getLogger("gprof_nn")
     handler = logging.handlers.QueueHandler(log_queue)
-    logging.basicConfig(
-        level=log_level,
-        format="%(message)s",
-        datefmt="[%X]",
-        handlers=[handler]
-    )
+    logger.propagate = False
+    logger.handlers = [handler]
 
 
 def log_messages():
@@ -95,5 +102,5 @@ def log_messages():
     if _LOG_QUEUE is not None:
         while _LOG_QUEUE.qsize():
             record = _LOG_QUEUE.get()
-            logger = logging.getLogger(record.name)
-            logger.handle(record)
+            for handler in LOGGER.handlers:
+                handler.emit(record)
