@@ -192,13 +192,14 @@ def combine_input_data_3d(dataset, sensor, v_tbs="brightness_temperatures"):
     return input_data
 
 
-def run_preprocessor_l1c(l1c_file, output_file):
+def run_preprocessor_l1c(l1c_file, configuration, output_file):
     """
     Run preprocessor on L1C file.
 
     Args:
         l1c_file: Path pointing to the L1C file on which to run the
             preprocessor.
+        configuration: The preprocessor configuration to run.
         output_file: The file to which to write the results.
 
     Raises:
@@ -206,8 +207,18 @@ def run_preprocessor_l1c(l1c_file, output_file):
     """
     sensor = L1CFile(l1c_file).sensor
     try:
-        LOGGER.info("Running preprocessor for input file %s.", l1c_file)
-        run_preprocessor(l1c_file, sensor, output_file=output_file, robust=False)
+        LOGGER.info(
+            "Running preprocessor for input file '%s' because the input file"
+            " is in L1C format.",
+            l1c_file,
+        )
+        run_preprocessor(
+            l1c_file,
+            sensor,
+            configuration=configuration,
+            output_file=output_file,
+            robust=False,
+        )
     except subprocess.CalledProcessError as e:
         LOGGER.error(
             (
@@ -248,7 +259,7 @@ class RetrievalDriver:
         compress=False,
         preserve_structure=False,
         sensor=None,
-        tile=False
+        tile=False,
     ):
         """
         Create retrieval driver.
@@ -285,16 +296,16 @@ class RetrievalDriver:
             self.output_format = output_format
         else:
             if output_file is None or Path(output_file).is_dir():
-                self.output_format = self.input_format
-            else:
-                if self.input_format in [NETCDF, L1C]:
+                if self.input_format == L1C:
                     self.output_format = NETCDF
                 else:
-                    output_file = Path(output_file)
-                    if output_file.suffix.lower() == ".bin":
-                        self.output_format = GPROF_BINARY
-                    else:
-                        self.output_format = NETCDF
+                    self.output_format = GPROF_BINARY
+            else:
+                output_file = Path(output_file)
+                if output_file.suffix.lower() == ".bin":
+                    self.output_format = GPROF_BINARY
+                else:
+                    self.output_format = NETCDF
 
         output_suffix = ".BIN"
         if self.output_format == NETCDF:
@@ -345,7 +356,10 @@ class RetrievalDriver:
         # Load input data.
         if self.input_format in [GPROF_BINARY, L1C]:
             input_data = self.model.preprocessor_class(
-                self.input_file, self.model.normalizer, tile=self.tile
+                self.input_file,
+                self.model.normalizer,
+                self.model.configuration,
+                tile=self.tile,
             )
         else:
             loader_class = self.model.netcdf_class
@@ -405,7 +419,10 @@ class RetrievalDriver:
         data = {}
         for k in means:
             y = np.concatenate([t.numpy() for t in means[k]])
-            data[k] = (input_data.dimensions[k], y)
+            if k in input_data.dimensions:
+                data[k] = (input_data.dimensions[k], y)
+            else:
+                data[k] = (input_data.scalar_dimensions, y)
 
         if len(precip_1st_tercile) > 0:
             dims = input_data.dimensions["surface_precip"]
@@ -468,18 +485,26 @@ class RetrievalDriver:
                 "two_meter_temperature",
                 "surface_type",
                 "airmass_type",
-                "scan_time"
+                "scan_time",
             ]
             for var in variables:
                 if var in input_data.data.variables:
-                    n_scans = results.scans.size
                     var_data = input_data.data[var].data
-                    if n_scans > var_data.shape[0]:
-                        var_data = upsample_scans(var_data, axis=0)
-                    dims = ("scans", "pixels")
-                    results[var] = (dims[:var_data.ndim], var_data)
+                    if list(input_data.data[var].dims)[0] == "samples":
+                        dims = ("samples", "scans", "pixels")
+                    else:
+                        if "scans" in input_data.data[var].dims:
+                            n_scans = results.scans.size
+                            if n_scans > var_data.shape[0]:
+                                var_data = upsample_scans(var_data, axis=0)
+                        dims = ("scans", "pixels")
+                    results[var] = (dims[: var_data.ndim], var_data)
 
-        LOGGER.info("Writing retrieval results to file '%s'.", self.output_file)
+        LOGGER.info(
+            "Writing retrieval results in '%s' format to file '%s'.",
+            self.output_format,
+            self.output_file,
+        )
         results.to_netcdf(self.output_file)
         if self.compress:
             LOGGER.info("Compressing file '%s'.", self.output_file)
@@ -488,6 +513,10 @@ class RetrievalDriver:
         else:
             output_file = self.output_file
 
+        # Delete input data to ensure that temporary resources
+        # are cleaned up.
+        del input_data
+
         return output_file
 
 
@@ -621,7 +650,9 @@ class NetcdfLoader1D(GPROF_NN_1D_Dataset):
     in NetCDF data format.
     """
 
-    def __init__(self, filename, normalizer, batch_size=16 * 1024, sensor=None, tile=False):
+    def __init__(
+        self, filename, normalizer, batch_size=16 * 1024, sensor=None, tile=False
+    ):
         """
         Create loader for input data in NetCDF format that provides input
         data for the GPROF-NN 1D retrieval.
@@ -675,7 +706,8 @@ class NetcdfLoader1D(GPROF_NN_1D_Dataset):
         """
         invalid = np.all(self.x[:, : self.sensor.n_chans] <= -1.5, axis=-1)
         for v in ALL_TARGETS:
-            data[v].data[invalid] = np.nan
+            if v in data:
+                data[v].data[invalid] = np.nan
 
         variables = [target for target in ALL_TARGETS if target in data.variables]
         for var in variables:
@@ -878,7 +910,9 @@ class ObservationLoader1D:
     file or a preprocessor file.
     """
 
-    def __init__(self, filename, file_class, normalizer, batch_size=1024 * 8, tile=False):
+    def __init__(
+        self, filename, file_class, normalizer, batch_size=1024 * 8, tile=False
+    ):
         """
         Create observation loader.
 
@@ -1006,7 +1040,14 @@ class PreprocessorLoader1D(ObservationLoader1D):
     to a preprocessor file.
     """
 
-    def __init__(self, filename, normalizer, batch_size=1024 * 16, tile=False):
+    def __init__(
+        self,
+        filename,
+        normalizer,
+        configuration,
+        batch_size=1024 * 16,
+        tile=False,
+    ):
         """
         Create preprocessor loader.
 
@@ -1015,18 +1056,20 @@ class PreprocessorLoader1D(ObservationLoader1D):
                 input data.
             normalizer: The normalizer object to use to normalize the input
                 data.
+            configuration: The preprocessor configuration to use to load
+                the data.
             batch_size: How many pixels should be processed simultaneously
                 in a single batch.
             tile: Has no effect for this loader.
         """
         suffix = filename.suffix
         if suffix.endswith("HDF5"):
-            with TemporaryDirectory() as tmp:
-                output_file = Path(tmp) / "input.pp"
-                run_preprocessor_l1c(filename, output_file)
-                super().__init__(
-                    output_file, PreprocessorFile, normalizer, batch_size=batch_size
-                )
+            self._tmp = TemporaryDirectory()
+            output_file = Path(self._tmp.name) / "input.pp"
+            run_preprocessor_l1c(filename, configuration, output_file)
+            super().__init__(
+                output_file, PreprocessorFile, normalizer, batch_size=batch_size
+            )
         else:
             LOGGER.info("Loading preprocessor input data from %s.", filename)
             super().__init__(
@@ -1044,7 +1087,7 @@ class L1CLoader1D(ObservationLoader1D):
     Interface class to load GPROF-NN 1D retrieval input from L1C files.
     """
 
-    def __init__(self, filename, normalizer, batch_size=1024 * 16):
+    def __init__(self, filename, normalizer, configuration, batch_size=1024 * 16):
         """
         Create L1C loader.
 
@@ -1053,6 +1096,7 @@ class L1CLoader1D(ObservationLoader1D):
                 input data.
             normalizer: The normalizer object to use to normalize the input
                 data.
+            configuration: Not used.
             batch_size: How many pixels should be processed simultaneously
                 in a single batch.
             tile: Has no effect for this loader.
@@ -1102,22 +1146,15 @@ class ObservationLoader3D:
         }
 
         if tile:
-            self.tiles, self.cuts = calculate_tiles_and_cuts(
-                self.n_scans,
-                256,
-                0
-            )
+            self.tiles, self.cuts = calculate_tiles_and_cuts(self.n_scans, 256, 0)
         else:
             self.tiles, self.cuts = calculate_tiles_and_cuts(
-                self.n_scans,
-                self.n_scans,
-                0
+                self.n_scans, self.n_scans, 0
             )
         self.batch_size = 4
         tile_0 = input_data[:, :, self.tiles[0]]
         self.padding = calculate_padding_dimensions(tile_0)
 
-
     def __len__(self):
         """
         The number of batches in the input file.
@@ -1127,7 +1164,6 @@ class ObservationLoader3D:
             n = n + 1
         return n
 
-
     def __getitem__(self, i):
         """
         Return batch of retrieval inputs as PyTorch tensor.
@@ -1140,9 +1176,8 @@ class ObservationLoader3D:
         """
         i_start = i * self.batch_size
         i_end = i_start + self.batch_size
-        tiles = self.tiles[i_start: i_end]
-        xs = [torch.tensor(self.input_data[:, :, tile])
-              for tile in tiles]
+        tiles = self.tiles[i_start:i_end]
+        xs = [torch.tensor(self.input_data[:, :, tile]) for tile in tiles]
         x = torch.cat(xs, 0)
         return nn.functional.pad(x, self.padding, mode="replicate")
 
@@ -1198,7 +1233,7 @@ class PreprocessorLoader3D(ObservationLoader3D):
     form preprocessor files.
     """
 
-    def __init__(self, filename, normalizer, tile=False):
+    def __init__(self, filename, normalizer, configuration, tile=False):
         """
         Create preprocessor loader.
 
@@ -1207,14 +1242,16 @@ class PreprocessorLoader3D(ObservationLoader3D):
                 input data.
             normalizer: The normalizer object to use to normalize the input
                 data.
+            configuration: The preprocessor configuration to use to load
+                the data.
             tile: Whether to tile the orbit in along track dimension.
         """
         suffix = filename.suffix
         if suffix.endswith("HDF5"):
-            with TemporaryDirectory() as tmp:
-                output_file = Path(tmp) / "input.pp"
-                run_preprocessor_l1c(filename, output_file)
-                super().__init__(output_file, PreprocessorFile, normalizer, tile=tile)
+            self._tmp = TemporaryDirectory()
+            output_file = Path(self._tmp.name) / "input.pp"
+            run_preprocessor_l1c(filename, configuration, output_file)
+            super().__init__(output_file, PreprocessorFile, normalizer, tile=tile)
         else:
             LOGGER.info("Loading preprocessor input data from %s.", filename)
             super().__init__(filename, PreprocessorFile, normalizer, tile=tile)
@@ -1231,7 +1268,7 @@ class L1CLoader3D(ObservationLoader3D):
     form L1C files.
     """
 
-    def __init__(self, filename, normalizer, tile=False):
+    def __init__(self, filename, normalizer, configuration, tile=False):
         """
         Create preprocessor loader.
 
@@ -1240,6 +1277,7 @@ class L1CLoader3D(ObservationLoader3D):
                 input data.
             normalizer: The normalizer object to use to normalize the input
                 data.
+            configuration: Not used.
             tile: Whether to tile the orbit in along track dimension.
         """
         super().__init__(filename, L1CFile, normalizer, tile=tile)
@@ -1251,7 +1289,7 @@ class L1CLoaderHR(ObservationLoader3D):
     form L1C files.
     """
 
-    def __init__(self, filename, normalizer, tile=False):
+    def __init__(self, filename, normalizer, configuration, tile=False):
         """
         Create preprocessor loader.
 
@@ -1260,27 +1298,21 @@ class L1CLoaderHR(ObservationLoader3D):
                 input data.
             normalizer: The normalizer object to use to normalize the input
                 data.
+            configuration: Not used.
             tile: Whether to tile the orbit in along track dimension.
         """
         super().__init__(filename, L1CFile, normalizer, tile=tile)
 
         if tile:
-            self.tiles, self.cuts = calculate_tiles_and_cuts(
-                self.n_scans,
-                256,
-                8
-            )
+            self.tiles, self.cuts = calculate_tiles_and_cuts(self.n_scans, 256, 8)
         else:
             self.tiles, self.cuts = calculate_tiles_and_cuts(
-                self.n_scans,
-                self.n_scans,
-                8
+                self.n_scans, self.n_scans, 8
             )
         self.batch_size = 4
         tile_0 = self.input_data[:, :, self.tiles[0]]
         self.padding = calculate_padding_dimensions(tile_0)
 
-
     def finalize(self, data):
         """
         Reshape retrieval results into shape of input data.
