@@ -18,7 +18,7 @@ GPM constellation. Most sensors exist in two or three variants:
      instance of the sensor plays a role, e.g. training of
      a retrieval model.
   3. A specific variant named using the naming scheme
-     {sensor}_{platform}_C. This sensor also applies a
+     sensor}_{platform}_C. This sensor also applies a
      quantile-matching correction to the training data.
 """
 from abc import ABC, abstractmethod, abstractproperty
@@ -86,7 +86,7 @@ def calculate_smoothing_kernel(
     y, x = np.meshgrid(x, x, indexing="ij")
     x = x * res_x_source / res_x_target
     y = y * res_a_source / res_a_target
-    w = np.exp(np.log(0.5) * (x ** 2 + y ** 2))
+    w = np.exp(np.log(0.5) * (x**2 + y**2))
     w = w / w.sum()
     return w
 
@@ -167,6 +167,36 @@ def calculate_bias_scaling(angles):
     return scales / _BIAS_SCALES_GMI
 
 
+def drop_inputs_from_sample(x, probability, sensor, rng):
+    """
+    Drop inputs from network input.
+
+    Args:
+        x: The input sample with channels/features along the first axis..
+        probability: The probability with which to drop a channels.
+        sensor: The sensor for which the data is extracted.
+        rng: Random generator object to use.
+    """
+    scalar_inputs = sensor.n_chans + 2
+    if isinstance(sensor, sensors.CrossTrackScanner):
+        scalar_input += 1
+    # Iterate of scalar variable and drop randomly
+    for i_ch in range(scalar_input):
+        r = rng.uniform()
+        if r <= probability:
+            x[i] = np.nan
+
+    # Drop surface type
+    r = rng.uniform()
+    if r <= probability:
+        x[scalar_input : scalar_inputs + 8] = np.nan
+
+    # Drop airmass type
+    r = rng.uniform()
+    if r <= probability:
+        x[scalar_input + 8 : scalar_inputs + 12] = np.nan
+
+
 ###############################################################################
 # Sensor classes
 ###############################################################################
@@ -191,6 +221,7 @@ class Sensor(ABC):
         self.platform = platform
         self.viewing_geometry = viewing_geometry
         self.missing_channels = None
+        self.l1c_version = ""
 
         # Bin file types
         self._bin_file_header = types.get_bin_file_header(n_chans, n_angles, kind)
@@ -333,6 +364,13 @@ class Sensor(ABC):
         """
         return self.platform.l1c_file_path
 
+    @l1c_file_path.setter
+    def l1c_file_path(self, path):
+        """
+        The default file path on the CSU system.
+        """
+        self.platform.l1c_file_path = path
+
     @abstractproperty
     def mrms_file_path(self):
         """
@@ -347,6 +385,14 @@ class Sensor(ABC):
         """
         return self._mrms_file_record
 
+    @mrms_file_record.setter
+    def mrms_file_record(self, record):
+        """
+        Numpy dtype defining the binary record structure for MRMS match
+        up files.
+        """
+        self._mrms_file_record = record
+
     @abstractproperty
     def sim_file_pattern(self):
         """
@@ -507,6 +553,7 @@ class ConicalScanner(Sensor):
     """
     Base class for conically-scanning sensors.
     """
+
     def __init__(
         self,
         name,
@@ -546,6 +593,10 @@ class ConicalScanner(Sensor):
     def mrms_file_path(self):
         return self._mrms_file_path
 
+    @mrms_file_path.setter
+    def mrms_file_path(self, path):
+        self._mrms_file_path = path
+
     @property
     def sim_file_pattern(self):
         return self._sim_file_pattern
@@ -554,6 +605,10 @@ class ConicalScanner(Sensor):
     def sim_file_path(self):
         return self._sim_file_path
 
+    @sim_file_path.setter
+    def sim_file_path(self, path):
+        self._sim_file_path = path
+
     def load_brightness_temperatures(self, data, angles=None, mask=None):
         return load_variable(data, "brightness_temperatures", mask=mask)
 
@@ -596,9 +651,12 @@ class ConicalScanner(Sensor):
             y_t = self.load_target(scene, t, valid)
             y_t = np.nan_to_num(y_t, nan=MASKED_OUTPUT)
             y[t] = y_t
+
         return x, y
 
-    def load_training_data_1d(self, dataset, targets, augment, rng, n_workers=1):
+    def load_training_data_1d(
+        self, dataset, targets, augment, rng, n_workers=1, drop_inputs=None
+    ):
         """
         Load training data for GPROF-NN 1D retrieval. This function will
         only load pixels that with a finite surface precip value in order
@@ -614,6 +672,10 @@ class ConicalScanner(Sensor):
             targets: List of the targets to load.
             augment: Whether or not to augment the training data.
             rng: Numpy random number generator to use for augmentation.
+            n_workers: If larger than 1, multiple processes will be load
+                the training data.
+            drop_inputs: A probability with which to set all inputs randomly
+                to a missing value.
 
         Return:
             Tuple ``(x, y)`` containing the un-batched, un-shuffled training
@@ -637,11 +699,16 @@ class ConicalScanner(Sensor):
             tasks = []
             for i in range(n_scenes):
                 scene = dataset[{"samples": i}]
-                tasks.append(pool.submit(
-                    ConicalScanner._load_scene_1d,
-                    self, scene, targets,
-                    augment,  rng
-                ))
+                tasks.append(
+                    pool.submit(
+                        ConicalScanner._load_scene_1d,
+                        self,
+                        scene,
+                        targets,
+                        augment,
+                        rng,
+                    )
+                )
 
             # Collect results
             for task in tasks:
@@ -653,11 +720,7 @@ class ConicalScanner(Sensor):
         else:
             for i in range(n_scenes):
                 scene = dataset[{"samples": i}]
-                x_i, y_i = self._load_scene_1d(
-                    scene,
-                    targets,
-                    augment,
-                    rng)
+                x_i, y_i = self._load_scene_1d(scene, targets, augment, rng)
                 x.append(x_i)
                 for target in targets:
                     y.setdefault(target, []).append(y_i[target])
@@ -669,9 +732,14 @@ class ConicalScanner(Sensor):
         if loaded:
             dataset.close()
 
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
-    def _load_scene_3d(self, scene, targets, augment, variables, rng, width, height):
+    def _load_scene_3d(
+        self, scene, targets, augment, variables, rng, width, height, drop_inputs=None
+    ):
         """
         Helper function for parallelized loading of training samples.
         """
@@ -749,10 +817,22 @@ class ConicalScanner(Sensor):
                 x = np.flip(x, -1)
                 for k in targets:
                     y[k] = np.flip(y[k], -1)
+
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
     def load_training_data_3d(
-            self, dataset, targets, augment, rng, width=96, height=128, n_workers=1
+        self,
+        dataset,
+        targets,
+        augment,
+        rng,
+        width=96,
+        height=128,
+        n_workers=1,
+        drop_inputs=None,
     ):
         """
         Load training data for GPROF-NN 3D retrieval. This function extracts
@@ -769,6 +849,8 @@ class ConicalScanner(Sensor):
             height: The height of each input image.
             n_workers: If larger than 1, a process pool with that many workers
                  will be used to load the data in parallel.
+            drop_inputs: A probability with which to set all inputs randomly
+                to a missing value.
 
         Return:
             Tuple ``(x, y)`` containing the un-batched, un-shuffled training
@@ -793,12 +875,20 @@ class ConicalScanner(Sensor):
             tasks = []
             for i in range(n_scenes):
                 scene = dataset[{"samples": i}]
-                tasks.append(pool.submit(
-                    ConicalScanner._load_scene_3d,
-                    self, scene, targets,
-                    augment, vs, rng,
-                    width, height
-                ))
+                tasks.append(
+                    pool.submit(
+                        ConicalScanner._load_scene_3d,
+                        self,
+                        scene,
+                        targets,
+                        augment,
+                        vs,
+                        rng,
+                        width,
+                        height,
+                        drop_inputs=drop_inputs,
+                    )
+                )
 
             # Collect results
             for task in tasks:
@@ -822,7 +912,9 @@ class ConicalScanner(Sensor):
                         vs,
                         rng,
                         width,
-                        height)
+                        height,
+                        drop_inputs=drop_inputs,
+                    )
                     x.append(x_i)
                     for target in targets:
                         y.setdefault(target, []).append(y_i[target])
@@ -834,6 +926,9 @@ class ConicalScanner(Sensor):
         if loaded:
             dataset.close()
 
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
 
@@ -842,6 +937,7 @@ class ConstellationScanner(ConicalScanner):
     This class represents conically-scanning sensors that are for which
     observations can only be simulated.
     """
+
     def __init__(
         self,
         name,
@@ -856,14 +952,20 @@ class ConstellationScanner(ConicalScanner):
         gmi_channels,
         correction=None,
         modeling_error=None,
-        latitude_ratios=None
+        latitude_ratios=None,
     ):
         super().__init__(
-            name, channels, angles, platform, viewing_geometry,
-            mrms_file_path, sim_file_pattern, sim_file_path
+            name,
+            channels,
+            angles,
+            platform,
+            viewing_geometry,
+            mrms_file_path,
+            sim_file_pattern,
+            sim_file_path,
         )
         self.nedt = nedt
-        self.gmi_channels=gmi_channels
+        self.gmi_channels = gmi_channels
         self.apply_biases = True
 
         if correction is None:
@@ -877,9 +979,7 @@ class ConstellationScanner(ConicalScanner):
 
         # MRMS types
         self._mrms_file_record = types.get_mrms_file_record(
-            self.n_chans,
-            self.n_angles,
-            types.CONICAL_CONST
+            self.n_chans, self.n_angles, types.CONICAL_CONST
         )
 
     @property
@@ -918,7 +1018,9 @@ class ConstellationScanner(ConicalScanner):
             tbs = load_variable(data, "brightness_temperatures", mask=mask)
         return tbs
 
-    def load_training_data_1d(self, dataset, targets, augment, rng, indices=None):
+    def load_training_data_1d(
+        self, dataset, targets, augment, rng, indices=None, drop_inputs=None
+    ):
         """
         Load training data for GPROF-NN 1D retrieval. This function will
         only load pixels that with a finite surface precip value in order
@@ -935,6 +1037,8 @@ class ConstellationScanner(ConicalScanner):
             rng: Numpy random number generator to use for augmentation.
             indices: List of scene indices from which to load the data. This
                 can be used to resample training scenes.
+            drop_inputs: A probability with which to set all inputs randomly
+                to a missing value.
 
         Return:
             Tuple ``(x, y)`` containing the un-batched, un-shuffled training
@@ -954,10 +1058,7 @@ class ConstellationScanner(ConicalScanner):
         # Iterate over samples in training data (scenes of size 221 x 221)
         # and extract only pixels for which surface precip is defined.
 
-        vs = [
-            "simulated_brightness_temperatures",
-            "brightness_temperature_biases"
-        ]
+        vs = ["simulated_brightness_temperatures", "brightness_temperature_biases"]
         if "surface_precip" not in targets:
             vs += ["surface_precip"]
 
@@ -973,18 +1074,10 @@ class ConstellationScanner(ConicalScanner):
 
             if source == 0:
                 tbs = scene["simulated_brightness_temperatures"].data
-                mask_tbs = get_mask(
-                    tbs, *LIMITS["simulated_brightness_temperatures"]
-                )
+                mask_tbs = get_mask(tbs, *LIMITS["simulated_brightness_temperatures"])
                 biases = scene["brightness_temperature_biases"].data
-                mask_biases = get_mask(
-                    biases, *LIMITS["brightness_temperature_biases"]
-                )
-                mask = (
-                    mask
-                    * np.all(mask_tbs, axis=-1)
-                    * np.all(mask_biases, axis=-1)
-                )
+                mask_biases = get_mask(biases, *LIMITS["brightness_temperature_biases"])
+                mask = mask * np.all(mask_tbs, axis=-1) * np.all(mask_biases, axis=-1)
             else:
                 tbs = scene["brightness_temperatures"].data
                 mask = mask * np.any((tbs > 0) * (tbs < 500), axis=-1)
@@ -999,7 +1092,7 @@ class ConstellationScanner(ConicalScanner):
             st = scene.surface_type.data[mask]
 
             if self.correction is not None:
-                tbs = self.correction(self, st, None, tcwv, tbs, augment=augment)
+                tbs = self.correction(rng, self, tbs, st, None, tcwv, augment=augment)
 
             # Add thermal noise to simulated observations.
             if augment and self.nedt is not None:
@@ -1038,10 +1131,13 @@ class ConstellationScanner(ConicalScanner):
         if loaded:
             dataset.close()
 
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
     def _load_training_data_3d_sim(
-        self, scene, targets, augment, rng, width=32, height=128
+        self, scene, targets, augment, rng, width=32, height=128, drop_inputs=None
     ):
         """
         Load training data for scene extracted from a sim file. Since
@@ -1056,6 +1152,8 @@ class ConstellationScanner(ConicalScanner):
             rng: 'numpy.random.Generator' to use to generate random numbers.
             width: The width of each input image.
             height: The height of each input image.
+            drop_inputs: A probability with which to set all inputs randomly
+                to a missing value.
 
         Returns:
             Tuple ``x, y`` containing one sample of training data for the
@@ -1093,7 +1191,7 @@ class ConstellationScanner(ConicalScanner):
         st = scene.surface_type.data
 
         if self.correction is not None:
-            tbs = self.correction(self, st, None, tcwv, tbs, augment=augment)
+            tbs = self.correction(rng, self, tbs, st, None, tcwv, augment=augment)
 
         if augment:
             if self.nedt is not None:
@@ -1169,10 +1267,14 @@ class ConstellationScanner(ConicalScanner):
                 x = np.flip(x, -1)
                 for k in targets:
                     y[k] = np.flip(y[k], -1)
+
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
     def _load_training_data_3d_other(
-        self, scene, targets, augment, rng, width=32, height=128
+        self, scene, targets, augment, rng, width=32, height=128, drop_inputs=None
     ):
         """
         Load training data for sea ice or snow surfaces. These observations
@@ -1187,6 +1289,8 @@ class ConstellationScanner(ConicalScanner):
             rng: 'numpy.random.Generator' to use to generate random numbers.
             width: The width of each input image.
             height: The height of each input image.
+            drop_inputs: A probability with which to set all inputs randomly
+                to a missing value.
 
         Returns:
             Tuple ``x, y`` containing one sample of training data for the
@@ -1227,7 +1331,6 @@ class ConstellationScanner(ConicalScanner):
         # Move channel to first dim.
         tbs = np.transpose(tbs, (2, 0, 1))
 
-
         t2m = self.load_two_meter_temperature(scene)
         t2m = t2m[np.newaxis, i_start:i_end, j_start:j_end]
 
@@ -1271,10 +1374,21 @@ class ConstellationScanner(ConicalScanner):
                 for k in targets:
                     y[k] = np.flip(y[k], -1)
 
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
     def load_training_data_3d(
-        self, dataset, targets, augment, rng, width=32, height=128, indices=None
+        self,
+        dataset,
+        targets,
+        augment,
+        rng,
+        width=32,
+        height=128,
+        indices=None,
+        drop_inputs=None,
     ):
         if isinstance(dataset, (str, Path)):
             dataset = xr.open_dataset(dataset)
@@ -1302,11 +1416,11 @@ class ConstellationScanner(ConicalScanner):
             source = scene.source
             if source == 0:
                 x_i, y_i = self._load_training_data_3d_sim(
-                    scene, targets, augment, rng, width=width, height=height
+                    scene, targets, augment, rng, width=width, height=height, drop_inputs=drop_inputs
                 )
             else:
                 x_i, y_i = self._load_training_data_3d_other(
-                    scene, targets, augment, rng, width=width, height=height
+                    scene, targets, augment, rng, width=width, height=height, drop_inputs=drop_inputs
                 )
             x.append(x_i)
             y.append(y_i)
@@ -1314,6 +1428,9 @@ class ConstellationScanner(ConicalScanner):
         x = np.stack(x)
         y = {k: np.stack([y_i[k] for y_i in y]) for k in y[0]}
 
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
 
@@ -1322,22 +1439,22 @@ class CrossTrackScanner(Sensor):
     Base class for cross-track-scanning sensors.
     """
     def __init__(
-            self,
-            name,
-            channels,
-            nedt,
-            angles,
-            platform,
-            viewing_geometry,
-            mrms_file_path,
-            sim_file_pattern,
-            sim_file_path,
-            gmi_channels,
-            correction=None,
-            modeling_error=None
+        self,
+        name,
+        channels,
+        nedt,
+        angles,
+        platform,
+        viewing_geometry,
+        mrms_file_path,
+        sim_file_pattern,
+        sim_file_path,
+        gmi_channels,
+        correction=None,
+        modeling_error=None,
     ):
         super().__init__(
-            types.XTRACK, "MHS", channels, angles, platform, viewing_geometry
+            types.XTRACK, name, channels, angles, platform, viewing_geometry
         )
         self.nedt = nedt
         n_chans = len(channels)
@@ -1346,8 +1463,9 @@ class CrossTrackScanner(Sensor):
 
         self.gmi_channels = np.array(gmi_channels)
         gmi_angles = GMI.angles[self.gmi_channels]
-        self.bias_scales = (np.cos(np.deg2rad(gmi_angles).reshape(1, -1)) /
-                            np.cos(np.deg2rad(self.angles).reshape(-1, 1)))
+        self.bias_scales = np.cos(np.deg2rad(gmi_angles).reshape(1, -1)) / np.cos(
+            np.deg2rad(self.angles).reshape(-1, 1)
+        )
         self.apply_biases = True
         self.bias_scaling = True
 
@@ -1385,6 +1503,10 @@ class CrossTrackScanner(Sensor):
     def mrms_file_path(self):
         return self._mrms_file_path
 
+    @mrms_file_path.setter
+    def mrms_file_path(self, path):
+        self._mrms_file_path = path
+
     @property
     def sim_file_pattern(self):
         return self._sim_file_pattern
@@ -1393,6 +1515,10 @@ class CrossTrackScanner(Sensor):
     def sim_file_path(self):
         return self._sim_file_path
 
+    @sim_file_path.setter
+    def sim_file_path(self, path):
+        self._sim_file_path = path
+
     @property
     def preprocessor_orbit_header(self):
         return self._preprocessor_orbit_header
@@ -1452,7 +1578,9 @@ class CrossTrackScanner(Sensor):
                 v = v[..., 0]
         return v
 
-    def load_training_data_1d(self, dataset, targets, augment, rng, indices=None):
+    def load_training_data_1d(
+        self, dataset, targets, augment, rng, indices=None, drop_inputs=None
+    ):
         """
         Load training data for GPROF-NN 1D retrieval. This function will
         only load pixels that with a finite surface precip value in order
@@ -1473,6 +1601,9 @@ class CrossTrackScanner(Sensor):
             targets: List of the targets to load.
             augment: Whether or not to augment the training data.
             rng: Numpy random number generator to use for augmentation.
+            indices: A list of scene indices to use to restrict the
+                training data to.
+            drop_inputs: A probability with which to drop inputs.
 
         Return:
             Tuple ``(x, y)`` containing the un-batched, un-shuffled training
@@ -1515,13 +1646,9 @@ class CrossTrackScanner(Sensor):
 
             if source == 0:
                 tbs = scene["simulated_brightness_temperatures"].data
-                mask_tbs = get_mask(
-                    tbs, *LIMITS["simulated_brightness_temperatures"]
-                )
+                mask_tbs = get_mask(tbs, *LIMITS["simulated_brightness_temperatures"])
                 biases = scene["brightness_temperature_biases"].data
-                mask_biases = get_mask(
-                    biases, *LIMITS["brightness_temperature_biases"]
-                )
+                mask_biases = get_mask(biases, *LIMITS["brightness_temperature_biases"])
                 mask = (
                     mask
                     * np.all(mask_tbs, axis=(-2, -1))
@@ -1551,7 +1678,7 @@ class CrossTrackScanner(Sensor):
             st = scene.surface_type.data[mask]
 
             if self.correction is not None:
-                tbs = self.correction(self, st, eia, tcwv, tbs, augment=augment)
+                tbs = self.correction(rng, self, tbs, st, eia, tcwv, augment=augment)
 
             if augment and self.nedt is not None:
                 noise = rng.normal(size=tbs.shape)
@@ -1576,6 +1703,9 @@ class CrossTrackScanner(Sensor):
                 y_t = np.nan_to_num(y_t, nan=MASKED_OUTPUT)
                 y.setdefault(t, []).append(y_t)
 
+            if drop_inputs is not None:
+                drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         x = np.concatenate(x, axis=0)
         y = {t: np.concatenate(y[t], axis=0) for t in y}
 
@@ -1585,7 +1715,14 @@ class CrossTrackScanner(Sensor):
         return x, y
 
     def _load_training_data_3d_sim(
-        self, scene, targets, augment, rng, width=32, height=128
+        self,
+        scene,
+        targets,
+        augment,
+        rng,
+        width=32,
+        height=128,
+        drop_inputs=None,
     ):
         """
         Load training data for scene extracted from a sim file. Since
@@ -1646,7 +1783,7 @@ class CrossTrackScanner(Sensor):
         st = scene.surface_type.data
 
         if self.correction is not None:
-            tbs = self.correction(self, st, eia, tcwv, tbs, augment=augment)
+            tbs = self.correction(rng, self, tbs, st, eia, tcwv, augment=augment)
 
         if augment:
             if self.nedt is not None:
@@ -1713,10 +1850,21 @@ class CrossTrackScanner(Sensor):
                 x = np.flip(x, -1)
                 for k in targets:
                     y[k] = np.flip(y[k], -1)
+
+        if drop_inputs is not None:
+            drop_inputs_from_sample(x, drop_inputs, self, rng)
+
         return x, y
 
     def _load_training_data_3d_other(
-        self, scene, targets, augment, rng, width=32, height=128
+        self,
+        scene,
+        targets,
+        augment,
+        rng,
+        width=32,
+        height=128,
+        drop_inputs=None,
     ):
         """
         Load training data for sea ice or snow surfaces. These observations
@@ -1813,10 +1961,13 @@ class CrossTrackScanner(Sensor):
                 for k in targets:
                     y[k] = np.flip(y[k], -1)
 
+        if drop_inputs is not None:
+            drop_inputs(x, drop_self, self, rng)
+
         return x, y
 
     def load_training_data_3d(
-        self, dataset, targets, augment, rng, width=32, height=128
+        self, dataset, targets, augment, rng, width=32, height=128, drop_inputs=None
     ):
         if isinstance(dataset, (str, Path)):
             dataset = xr.open_dataset(dataset)
@@ -1843,11 +1994,23 @@ class CrossTrackScanner(Sensor):
             source = scene.source
             if source == 0:
                 x_i, y_i = self._load_training_data_3d_sim(
-                    scene, targets, augment, rng, width=width, height=height
+                    scene,
+                    targets,
+                    augment,
+                    rng,
+                    width=width,
+                    height=height,
+                    drop_inputs=drop_inputs,
                 )
             else:
                 x_i, y_i = self._load_training_data_3d_other(
-                    scene, targets, augment, rng, width=width, height=height
+                    scene,
+                    targets,
+                    augment,
+                    rng,
+                    width=width,
+                    height=height,
+                    drop_inputs=drop_inputs,
                 )
             x.append(x_i)
             y.append(y_i)
@@ -1869,12 +2032,8 @@ class Platform:
     is flown on. It is used to hold information that is specifc to that
     platform such as the data path and the prefix of L1C files.
     """
-    def __init__(
-            self,
-            name,
-            l1c_file_path,
-            l1c_file_prefix
-    ):
+
+    def __init__(self, name, l1c_file_path, l1c_file_prefix):
         self.name = name
         self.l1c_file_path = l1c_file_path
         self.l1c_file_prefix = l1c_file_prefix
@@ -1888,14 +2047,12 @@ class Platform:
 
 TRMM = Platform("TRMM", "/pdata4/archive/GPM/1C_TMI_ITE/", "1C.TRMM.TMI")
 NOAA19 = Platform("NOAA19", "/pdata4/archive/GPM/1C_NOAA19_ITE/", "1C.NOAA19.MHS")
-GPM = Platform("GPM-CO", "/pdata4/archive/GPM/1CR_GMI_ITE/", "1C-R.GPM.GMI")
+NPP = Platform("NPP", "/pdata4/archive/GPM/1C_ATMS_ITE/", "1C.NPP.ATMS")
+GPM = Platform("GPM-CO", "/pdata4/archive/GPM/1CR_GMI_V7/", "1C-R.GPM.GMI")
 F15 = Platform("F15", "/pdata4/archive/GPM/1C_F15_ITE/", "1C.F15.SSMI")
 F17 = Platform("F17", "/pdata4/archive/GPM/1C_F17_ITE/", "1C.F17.SSMIS")
-GCOMW1 = Platform(
-    "GCOM-W1",
-    "/pdata4/archive/GPM/1C_AMSR2_ITE/",
-    "1C.GCOMW1.AMSR2"
-)
+GCOMW1 = Platform("GCOM-W1", "/pdata4/archive/GPM/1C_AMSR2_ITE/", "1C.GCOMW1.AMSR2")
+AQUA = Platform("AQUA", "/pdata4/archive/GPM/1C_AMSRE/", "1C.AQUA.AMSRE")
 
 ###############################################################################
 # GMI
@@ -1920,23 +2077,25 @@ GMI_CHANNELS = [
 ]
 
 
-GMI_ANGLES = np.array([
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    -9999.9,
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    49.19,
-    49.19,
-    -9999.9,
-    49.19,
-    49.19,
-])
+GMI_ANGLES = np.array(
+    [
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        -9999.9,
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        49.19,
+        49.19,
+        -9999.9,
+        49.19,
+        49.19,
+    ]
+)
 
 
 GMI_VIEWING_GEOMETRY = Conical(
@@ -1964,7 +2123,7 @@ GMI = ConicalScanner(
 ###############################################################################
 
 MHS_ANGLES = np.array(
-    [59.798, 53.311, 46.095, 39.222, 32.562, 26.043, 19.619, 13.257, 6.934, 0.0]
+    [59.498, 53.311, 46.095, 39.222, 32.562, 26.043, 19.619, 13.257, 6.934, 0.0]
 )
 
 MHS_CHANNELS = [
@@ -1975,14 +2134,14 @@ MHS_CHANNELS = [
     (190.0, "H"),
 ]
 
-MHS_NEDT = np.array([0.3, 0.5, 3.8, 0.7, 0.3])
+MHS_NEDT = np.array([0.3, 0.5, 0.5, 0.5, 0.5])
 
 MHS_VIEWING_GEOMETRY = CrossTrack(
     altitude=855e3,
     scan_range=2.0 * 49.5,
     pixels_per_scan=90,
     scan_offset=17e3,
-    beam_width=1.1
+    beam_width=1.1,
 )
 
 MHS_GMI_CHANNELS = [8, 11, 13, 13, 14]
@@ -1996,10 +2155,38 @@ MHS = CrossTrackScanner(
     MHS_VIEWING_GEOMETRY,
     "/pdata4/veljko/MHS2MRMS_match2019/monthly_2021/",
     "MHS.dbsatTb.??????{day}.??????.sim",
-    "/qdata1/pbrown/dbaseV7/simV7x",
+    "/qdata1/pbrown/dbaseV7/simV7x_mhs",
     MHS_GMI_CHANNELS,
     correction=DATA_FOLDER / "corrections_mhs.nc",
-    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0]
+    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0],
+)
+
+MHS_GPROF = CrossTrackScanner(
+    "MHS",
+    MHS_CHANNELS,
+    MHS_NEDT,
+    MHS_ANGLES,
+    NOAA19,
+    MHS_VIEWING_GEOMETRY,
+    "/pdata4/veljko/MHS2MRMS_match2019/monthly_2021/",
+    "MHS.dbsatTb.??????{day}.??????.sim",
+    "/qdata1/pbrown/dbaseV7/simV7x_mhs",
+    MHS_GMI_CHANNELS,
+    correction=DATA_FOLDER / "corrections_mhs_gprof.nc",
+    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0],
+)
+
+MHS_NO_CORRECTION = CrossTrackScanner(
+    "MHS",
+    MHS_CHANNELS,
+    MHS_NEDT,
+    MHS_ANGLES,
+    NOAA19,
+    MHS_VIEWING_GEOMETRY,
+    "/pdata4/veljko/MHS2MRMS_match2019/monthly_2021/",
+    "MHS.dbsatTb.??????{day}.??????.sim",
+    "/qdata1/pbrown/dbaseV7/simV7x_mhs",
+    MHS_GMI_CHANNELS,
 )
 
 MHS_NOAA19 = CrossTrackScanner(
@@ -2011,10 +2198,10 @@ MHS_NOAA19 = CrossTrackScanner(
     MHS_VIEWING_GEOMETRY,
     "/pdata4/veljko/MHS2MRMS_match2019/monthly_2021/",
     "MHS.dbsatTb.??????{day}.??????.sim",
-    "/qdata1/pbrown/dbaseV7/simV7x",
+    "/qdata1/pbrown/dbaseV7/simV7x_mhs",
     MHS_GMI_CHANNELS,
     correction=DATA_FOLDER / "corrections_mhs_noaa19.nc",
-    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0]
+    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0],
 )
 
 MHS_NOAA19_FULL = CrossTrackScanner(
@@ -2026,10 +2213,10 @@ MHS_NOAA19_FULL = CrossTrackScanner(
     MHS_VIEWING_GEOMETRY,
     "/pdata4/veljko/MHS2MRMS_match2019/monthly_2021/",
     "MHS.dbsatTb.??????{day}.??????.sim",
-    "/qdata1/pbrown/dbaseV7/simV7x",
+    "/qdata1/pbrown/dbaseV7/simV7x_mhs",
     MHS_GMI_CHANNELS,
     correction=DATA_FOLDER / "corrections_mhs_noaa19_full.nc",
-    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0]
+    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0],
 )
 
 
@@ -2051,6 +2238,7 @@ def get_sensor(sensor, platform=None, date=None):
 
     return sensor
 
+
 ###############################################################################
 # TMI
 ###############################################################################
@@ -2067,29 +2255,21 @@ TMI_CHANNELS = [
     (85.5, "H"),
 ]
 
-TMI_ANGLES = np.array([
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-    52.8,
-])
+TMI_ANGLES = np.array(
+    [
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+        52.8,
+    ]
+)
 
-TMI_NEDT = np.array([
-    0.63,
- 	0.54,
- 	0.50,
- 	0.47,
- 	0.71,
- 	0.36,
- 	0.31,
- 	0.52,
- 	0.93
-])
+TMI_NEDT = np.array([0.63, 0.54, 0.50, 0.47, 0.71, 0.36, 0.31, 0.52, 0.93])
 
 TMI_GMI_CHANNELS = [0, 1, 2, 3, 4, 6, 7, 8, 9]
 
@@ -2109,17 +2289,7 @@ TMIPO_VIEWING_GEOMETRY = Conical(
     scan_offset=13.4e3,
 )
 
-TMIPR_MODELING_ERROR = np.sqrt(np.array([
-    1.1,
-    2.4,
-    1.0,
-    2.6,
-    0.9,
-    2.0,
-    7.1,
-    2.4,
-    6.1
-]))
+TMIPR_MODELING_ERROR = np.sqrt(np.array([1.1, 2.4, 1.0, 2.6, 0.9, 2.0, 7.1, 2.4, 6.1]))
 
 TMIPR_NC = ConstellationScanner(
     "TMIPR",
@@ -2131,7 +2301,7 @@ TMIPR_NC = ConstellationScanner(
     None,
     "TMIPR.dbsatTb.??????{day}.??????.sim",
     "/qdata1/pbrown/dbaseV7/simV7_tmi",
-    TMI_GMI_CHANNELS
+    TMI_GMI_CHANNELS,
 )
 
 TMIPR = ConstellationScanner(
@@ -2147,7 +2317,7 @@ TMIPR = ConstellationScanner(
     TMI_GMI_CHANNELS,
     correction=DATA_FOLDER / "corrections_tmipr.nc",
     modeling_error=TMIPR_MODELING_ERROR,
-    latitude_ratios= DATA_FOLDER / "latitude_ratios_tmipr.npy"
+    latitude_ratios=DATA_FOLDER / "latitude_ratios_tmipr.npy",
 )
 
 
@@ -2163,7 +2333,7 @@ TMIPO = ConstellationScanner(
     "/qdata1/pbrown/dbaseV7/simV7_tmi",
     TMI_GMI_CHANNELS,
     correction=DATA_FOLDER / "corrections_tmipo.nc",
-    latitude_ratios= DATA_FOLDER / "latitude_ratios_tmipo.npy"
+    latitude_ratios=DATA_FOLDER / "latitude_ratios_tmipo.npy",
 )
 
 TMI = TMIPR
@@ -2182,35 +2352,43 @@ SSMI_CHANNELS = [
     (85.5, "V"),
 ]
 
-SSMI_ANGLES = np.array([
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-])
+SSMI_ANGLES = np.array(
+    [
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+    ]
+)
 
-SSMI_NEDT = np.array([
-    0.63,
- 	0.54,
- 	0.50,
- 	0.47,
- 	0.71,
- 	0.36,
- 	0.31,
-])
+SSMI_NEDT = np.array(
+    [
+        0.63,
+        0.54,
+        0.50,
+        0.47,
+        0.71,
+        0.36,
+        0.31,
+    ]
+)
 
-SSMI_MODELING_ERROR = np.sqrt(np.array([
-    1.0,
-    1.5,
-    0.5,
-    1.0,
-    2.0,
-    1.5,
-    2.0,
-]))
+SSMI_MODELING_ERROR = np.sqrt(
+    np.array(
+        [
+            1.0,
+            1.5,
+            0.5,
+            1.0,
+            2.0,
+            1.5,
+            2.0,
+        ]
+    )
+)
 
 SSMI_GMI_CHANNELS = [2, 3, 4, 6, 7, 8, 9]
 
@@ -2268,63 +2446,59 @@ SSMIS_CHANNELS = [
     (150, "H"),
     (189, "H"),
     (186, "H"),
-    (184, "H")
+    (184, "H"),
 ]
 
-SSMIS_ANGLES = np.array([
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-])
+SSMIS_ANGLES = np.array(
+    [
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+    ]
+)
 
-SSMIS_NEDT = np.array([
-    0.7,
- 	0.7,
- 	0.7,
- 	0.5,
- 	0.5,
- 	0.9,
- 	0.9,
- 	1.0,
- 	1.0,
- 	1.0,
- 	1.0,
-])
+SSMIS_NEDT = np.array(
+    [
+        0.7,
+        0.7,
+        0.7,
+        0.5,
+        0.5,
+        0.9,
+        0.9,
+        1.0,
+        1.0,
+        1.0,
+        1.0,
+    ]
+)
 
-SSMIS_MODELING_ERROR = np.sqrt(np.array([
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-]))
+SSMIS_MODELING_ERROR = np.sqrt(
+    np.array(
+        [
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+        ]
+    )
+)
 
-SSMIS_GMI_CHANNELS = [
-    2,
-    3,
-    4,
-    6,
-    7,
-    8,
-    9,
-    11,
-    14,
-    14,
-    13
-]
+SSMIS_GMI_CHANNELS = [2, 3, 4, 6, 7, 8, 9, 11, 14, 14, 13]
 
 
 SSMIS_VIEWING_GEOMETRY = Conical(
@@ -2369,57 +2543,41 @@ AMSR2_CHANNELS = [
     (89, "H"),
 ]
 
-AMSR2_ANGLES = np.array([
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-    53.1,
-])
+AMSR2_ANGLES = np.array(
+    [
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+        53.1,
+    ]
+)
 
-AMSR2_NEDT = np.array([
-    0.7,
-    0.7,
-    0.7,
-    0.7,
-    0.6,
-    0.6,
-    0.7,
-    0.7,
-    1.2,
-    1.4
-])
+AMSR2_NEDT = np.array([0.7, 0.7, 0.7, 0.7, 0.6, 0.6, 0.7, 0.7, 1.2, 1.4])
 
-AMSR2_MODELING_ERROR = np.sqrt(np.array([
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-    2.0,
-]))
+AMSR2_MODELING_ERROR = np.sqrt(
+    np.array(
+        [
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+        ]
+    )
+)
 
-AMSR2_GMI_CHANNELS = [
-    0,
-    1,
-    2,
-    3,
-    4,
-    4,
-    6,
-    7,
-    8,
-    9
-]
+AMSR2_GMI_CHANNELS = [0, 1, 2, 3, 4, 4, 6, 7, 8, 9]
 
 AMSR2_VIEWING_GEOMETRY = Conical(
     altitude=700e3,
@@ -2443,3 +2601,138 @@ AMSR2 = ConstellationScanner(
     modeling_error=AMSR2_MODELING_ERROR,
     correction=DATA_FOLDER / "corrections_amsr2.nc",
 )
+
+
+###############################################################################
+# AMSR-E
+###############################################################################
+
+AMSRE_CHANNELS = [
+    (10.65, "V"),
+    (10.65, "H"),
+    (18.7, "V"),
+    (18.7, "H"),
+    (23.8, "V"),
+    (23.8, "H"),
+    (36.5, "V"),
+    (36.5, "H"),
+    (89, "V"),
+    (89, "H"),
+]
+
+AMSRE_ANGLES = np.array(
+    [
+        55.0,
+        55.0,
+        55.0,
+        55.0,
+        55.0,
+        55.0,
+        55.0,
+        55.0,
+        55.0,
+        55.0,
+    ]
+)
+
+AMSRE_NEDT = np.array([0.3, 0.6, 0.6, 0.6, 0.6, 0.6, 0.6, 0.6, 1.1, 1.1])
+
+AMSRE_MODELING_ERROR = np.sqrt(
+    np.array(
+        [
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+            2.0,
+        ]
+    )
+)
+
+AMSRE_GMI_CHANNELS = [
+    0,
+    1,
+    2,
+    3,
+    4,
+    4,
+    5,
+    6,
+    7,
+    8,
+]
+
+AMSRE_VIEWING_GEOMETRY = Conical(
+    altitude=703e3,
+    earth_incidence_angle=55.0,
+    scan_range=140,
+    pixels_per_scan=180,
+    scan_offset=12.5e3,
+)
+
+AMSRE = ConstellationScanner(
+    "AMSRE",
+    AMSRE_CHANNELS,
+    AMSRE_NEDT,
+    AMSRE_ANGLES,
+    AQUA,
+    AMSRE_VIEWING_GEOMETRY,
+    "/pdata4/veljko/AMSR22MRMS_match2019/monthly_2021/",
+    "AMSRE.dbsatTb.??????{day}.??????.sim",
+    "/qdata1/pbrown/dbaseV7/simV7_amsre",
+    AMSRE_GMI_CHANNELS,
+    modeling_error=AMSRE_MODELING_ERROR,
+    correction=DATA_FOLDER / "corrections_amsre.nc",
+)
+
+
+AMSRE.mrms_sensor = AMSR2
+
+###############################################################################
+# ATMS
+###############################################################################
+
+ATMS_ANGLES = np.array(
+    [59.498, 53.311, 46.095, 39.222, 32.562, 26.043, 19.619, 13.257, 6.934, 0.0]
+)
+
+ATMS_CHANNELS = [
+    (88.2, "V"),
+    (165.5, "H"),
+    (184.0, "V"),
+    (186.0, "V"),
+    (190.0, "H"),
+]
+
+ATMS_NEDT = np.array([0.3, 0.5, 0.5, 0.5, 0.5])
+
+ATMS_VIEWING_GEOMETRY = CrossTrack(
+    altitude=855e3,
+    scan_range=2.0 * 52.725,
+    pixels_per_scan=96,
+    scan_offset=16e3,
+    beam_width=1.5,
+)
+
+ATMS_GMI_CHANNELS = [8, 11, 13, 13, 14]
+
+ATMS = CrossTrackScanner(
+    "ATMS",
+    ATMS_CHANNELS,
+    ATMS_NEDT,
+    ATMS_ANGLES,
+    NPP,
+    ATMS_VIEWING_GEOMETRY,
+    "/pdata4/veljko/MHS2MRMS_match2019/monthly_2021/",
+    "ATMS.dbsatTb.??????{day}.??????.sim",
+    "/qdata1/pbrown/dbaseV7/simV7x_atms",
+    ATMS_GMI_CHANNELS,
+    correction=DATA_FOLDER / "corrections_atms.nc",
+    modeling_error=[3.0, 2.0, 2.0, 2.0, 2.0],
+)
+ATMS.mrms_sensor = MHS
