@@ -61,8 +61,6 @@ def test_read_preprocessor_gmi():
     assert np.all((tcwv >= 0) * (tcwv < 200))
 
     date = input_file.first_scan_time
-    print(date)
-    print(input_data.scan_time[0])
     assert date == input_data.scan_time[0].data
 
 
@@ -99,8 +97,6 @@ def test_read_preprocessor_mhs():
     assert np.all((tcwv >= 0) * (tcwv < 200))
 
     date = input_file.first_scan_time
-    print(date)
-    print(input_data.scan_time[0])
     assert date == input_data.scan_time[0].data
 
 
@@ -118,7 +114,6 @@ def test_read_preprocessor_tmi():
 
     tbs = input_data.brightness_temperatures.data
     tbs = tbs[tbs > 0]
-    print(tbs.min(), tbs.max())
     assert np.all((tbs > 20) * (tbs <= 350))
 
     st = input_data.surface_type.data
@@ -139,8 +134,6 @@ def test_read_preprocessor_tmi():
     assert np.all((tcwv >= 0) * (tcwv < 200))
 
     date = input_file.first_scan_time
-    print(date)
-    print(input_data.scan_time[0])
     assert date == input_data.scan_time[0].data
 
 
@@ -158,7 +151,6 @@ def test_read_preprocessor_ssmi():
 
     tbs = input_data.brightness_temperatures.data
     tbs = tbs[tbs > 0]
-    print(tbs.min(), tbs.max())
     assert np.all((tbs > 20) * (tbs <= 350))
 
     st = input_data.surface_type.data
@@ -179,8 +171,6 @@ def test_read_preprocessor_ssmi():
     assert np.all((tcwv >= 0) * (tcwv < 200))
 
     date = input_file.first_scan_time
-    print(date)
-    print(input_data.scan_time[0])
     assert date == input_data.scan_time[0].data
 
 
@@ -218,8 +208,6 @@ def test_read_preprocessor_ssmis():
     assert np.all((tcwv >= 0) * (tcwv < 200))
 
     date = input_file.first_scan_time
-    print(date)
-    print(input_data.scan_time[0])
     assert date == input_data.scan_time[0].data
 
 
@@ -259,8 +247,46 @@ def test_read_preprocessor_amsr2():
     assert np.all((tcwv >= 0) * (tcwv < 200))
 
     date = input_file.first_scan_time
-    print(date)
-    print(input_data.scan_time[0])
+    assert date == input_data.scan_time[0].data
+
+
+def test_read_preprocessor_atms():
+    """
+    Tests reading a ATMS preprocessor file.
+    """
+    DATA_PATH = Path(__file__).parent / "data"
+    input_file = PreprocessorFile(
+        DATA_PATH / "atms" / "pp" /
+        "1C.NPP.ATMS.XCAL2019-V.20181001-S004905-E023034.035889.ITE753.pp"
+    )
+    input_data = input_file.to_xarray_dataset()
+
+    assert input_file.n_pixels == 90
+    assert input_data.pixels.size == 90
+    assert input_data.scans.size == input_file.n_scans
+
+    tbs = input_data.brightness_temperatures.data
+    tbs = tbs[tbs > 0]
+    assert np.all((tbs > 20) * (tbs <= 350))
+
+    st = input_data.surface_type.data
+    assert np.all((st >= -99) * (st <= 18))
+
+    am = input_data.airmass_type.data
+    am = am[am >= 0]
+    assert np.all((am >= 0) * (am <= 18))
+
+    lat = input_data.latitude
+    assert np.all((lat >= -9999) * (lat <= 90))
+    lon = input_data.longitude
+    assert np.all((lat >= -9999) * (lat <= 180))
+
+    t2m = input_data.two_meter_temperature
+    assert np.all((t2m > -9999) * (t2m < 400))
+    tcwv = input_data.total_column_water_vapor
+    assert np.all((tcwv >= -9999) * (tcwv < 200))
+
+    date = input_file.first_scan_time
     assert date == input_data.scan_time[0].data
 
 
@@ -574,6 +600,45 @@ def test_run_preprocessor_amsr2_era5():
     assert np.all((tcwv >= 0) * (tcwv < 200))
 
 
+@pytest.mark.skipif(not HAS_PREPROCESSOR, reason="Preprocessor missing.")
+def test_run_preprocessor_atms_era5():
+    """
+    Test running the ATMS preprocessor on a specific L1C file.
+    """
+    l1c_path = Path("/pdata4/archive/GPM/1C_ATMS_ITE")
+    date = datetime(2018, 10, 1, 1, 30)
+    l1c_file = L1CFile.find_file(
+        date,
+        l1c_path,
+        sensor=sensors.ATMS,
+    )
+    data = run_preprocessor(l1c_file.filename, sensor=sensors.ATMS)
+
+    tbs = data.brightness_temperatures.data
+    valid = np.all(tbs > 0, axis=-1)
+    tbs = tbs[valid]
+    assert np.all((tbs > 20) * (tbs <= 350))
+
+    st = data.surface_type.data
+    valid = st >= 0
+    assert np.all((st[valid] >= 0) * (st[valid] <= 18))
+
+    am = data.airmass_type.data[valid]
+    am = am[am >= 0]
+    assert np.all((am >= 0) * (am <= 18))
+
+    lat = data.latitude.data[valid]
+    assert np.all((lat >= -90) * (lat <= 90))
+    lon = data.longitude.data[valid]
+    assert np.all((lon >= -180) * (lon <= 180))
+
+    t2m = data.two_meter_temperature.data[valid]
+    assert np.all((t2m > 200) * (t2m < 400))
+    tcwv = data.total_column_water_vapor.data[valid]
+    tcwv = tcwv[tcwv >= 0]
+    assert np.all((tcwv >= 0) * (tcwv < 200))
+
+
 def test_calculate_frozen_precip():
     """
     That below -6.5 all precip is frozen and above all precip is liquid.
